@@ -834,6 +834,9 @@ main(int argc, char *argv[])
 {
   gtk_init(&argc, &argv);
 
+  /* Set the window icon */
+  gtk_window_set_default_icon_name ("oprofile-viewer");
+
   /* load the interface */
   if (g_file_test (SOURCE_GLADE, G_FILE_TEST_EXISTS) != FALSE) {
     xml = glade_xml_new (SOURCE_GLADE, NULL, NULL);
